@@ -237,8 +237,8 @@ class TPEGLoader(object):
     @classmethod
     def fileName(cls, urn, file):
         if file.startswith('CJDIC'):
-            file = file.replace('CJDIC', os.environ.get('CJDIC', 'cjdic'))
-            return Path(file)
+            file = file.replace('CJDIC', os.environ.get('CJDIC', '__unknown__'))
+            return None if '__unknown__' in file else Path(file)
         return Path(urn).parent / file
 
     @classmethod
@@ -247,13 +247,14 @@ class TPEGLoader(object):
         for e in es:
             filename = str(e)[1:-1]
             file = TPEGLoader.fileName(urn, filename)
+            if file is None:
+                continue
             try:
                 with file.open(encoding='utf-8_sig') as f:
                     ss = [x.strip('\r\n') for x in f.readlines()]
                     ds |= fset(ss, n)
             except:
-                if not filename.startswith('CJDIC'):
-                    print(f'File Not Found: {file}')
+                print(f'can\'t read: {filename} {file}')
         choice = [PChar(x) for x in sorted(ds, key=lambda x: len(x))[::-1]]
         return POre.new(*choice)
 
@@ -320,8 +321,8 @@ def load_grammar(peg, file_or_text, **options):
         f = file_or_text.open(encoding=options.get('encoding', 'utf-8_sig'))
         data = f.read()
         f.close()
-        ptree = TPEGParser(data, options.get('urn', file_or_text))
         basepath = str(file_or_text)
+        ptree = TPEGParser(data, basepath)
     else:
         if 'basepath' in options:
             basepath = options['basepath']
@@ -342,7 +343,7 @@ def findpath(paths, file_or_text):
     for p in paths:
         path = Path(p) / file_or_text
         if path.is_file():
-            return path.resolve()
+            return path.absolute()
     raise FileNotFoundError(errno.ENOENT, os.strerror(errno.ENOENT), file_or_text)
 
 GrammarDB = {}
